@@ -19,7 +19,7 @@ class Job:
 			url = f'{API_URL}/jobs'
 			json = {'task': self.task, 'trigger': self.trigger}
 			response = requests.post(url, headers=self.headers, json=json)
-			self.uuid = response.json().get('uuid')
+			self.uuid = response.json()
 			return response.json()
 		
 		return self
